diff --git a/system/dbupdate_3.3.php b/system/dbupdate_3.3.php
index f21e6b3f7..d401b7efb 100644
--- a/system/dbupdate_3.3.php
+++ b/system/dbupdate_3.3.php
@@ -4019,16 +4019,16 @@ if (!$result = @$db->db_query('SELECT 1 FROM system.tbl_jobtriggers LIMIT 1'))
echo '
Granted privileges to vilesci on system.tbl_jobtriggers';
}
-// Add column ISO-3166-1-A-2 to bis.tbl_nation
-if (!$result = @$db->db_query("SELECT ISO-3166-1-A-2 FROM bis.tbl_nation LIMIT 1"))
+// Add column iso3166_1_a2 to bis.tbl_nation
+if (!$result = @$db->db_query("SELECT iso3166_1_a2 FROM bis.tbl_nation LIMIT 1"))
{
- $qry = "ALTER TABLE bis.tbl_nation ADD COLUMN \"ISO-3166-1-A-2\" character varying(2);";
- $qry .= "COMMENT ON COLUMN bis.tbl_nation.\"ISO-3166-1-A-2\" IS 'ISO 3166-1 alpha-2 country code';";
+ $qry = "ALTER TABLE bis.tbl_nation ADD COLUMN iso3166_1_a2 character varying(2);";
+ $qry .= "COMMENT ON COLUMN bis.tbl_nation.iso3166_1_a2 IS 'ISO 3166-1 alpha-2 country code';";
if(!$db->db_query($qry))
- echo 'bis.tbl_nation.ISO-3166-1-A-2: '.$db->db_last_error().'
';
+ echo 'bis.tbl_nation.iso3166_1_a2: '.$db->db_last_error().'
';
else
- echo '
bis.tbl_nation.ISO-3166-1-A-2: Spalte ISO-3166-1-A-2 hinzugefuegt';
+ echo '
bis.tbl_nation.iso3166_1_a2: Spalte iso3166_1_a2 hinzugefuegt';
}
// *** Pruefung und hinzufuegen der neuen Attribute und Tabellen
@@ -4060,7 +4060,7 @@ $tabellen=array(
"bis.tbl_mobilitaet" => array("mobilitaet_id","prestudent_id","mobilitaetstyp_kurzbz","studiensemester_kurzbz","mobilitaetsprogramm_code","gsprogramm_id","firma_id","status_kurzbz","ausbildungssemester","insertvon","insertamum","updatevon","updateamum"),
"bis.tbl_mobilitaetstyp" => array("mobilitaetstyp_kurzbz","bezeichnung","aktiv"),
"bis.tbl_mobilitaetsprogramm" => array("mobilitaetsprogramm_code","kurzbz","beschreibung","sichtbar","sichtbar_outgoing"),
- "bis.tbl_nation" => array("nation_code","entwicklungsstand","eu","ewr","kontinent","kurztext","langtext","engltext","sperre","nationengruppe_kurzbz", "ISO-3166-1-A-2"),
+ "bis.tbl_nation" => array("nation_code","entwicklungsstand","eu","ewr","kontinent","kurztext","langtext","engltext","sperre","nationengruppe_kurzbz", "iso3166_1_a2"),
"bis.tbl_nationengruppe" => array("nationengruppe_kurzbz","nationengruppe_bezeichnung","aktiv"),
"bis.tbl_orgform" => array("orgform_kurzbz","code","bezeichnung","rolle","bisorgform_kurzbz","bezeichnung_mehrsprachig"),
"bis.tbl_verwendung" => array("verwendung_code","verwendungbez"),